@@ -37,7 +37,7 @@ sub format_content {
     my ($class,$content,$c)=@_;
 
     my @lines=split /\n/,$$content;
-    my $pod;$$content="";
+    $$content="";
     foreach my $line (@lines) {
         if ($line =~ m/^=(http\:\/\/\S+)$/) { 
             $$content.=$class->include($c,$1);
@@ -56,9 +56,13 @@ $c->cache
 
 sub include {
     my ($class,$c,$url)=@_;
+    $url=URI->new($url);
+    return "$url is not a valid url." unless $url;
+    my $rel=$url->rel($c->req->base);
+    return "$url is part of own site, cannot include." unless $rel->scheme;
     my $res=URI::Fetch->fetch($url,Cache=>$c->cache);
     return $res->content if defined $res;
-    return "Could not retrieve $url .\n";
+    return "Could not  retrieve $url.\n";
 }
 
 =back
